# 🚀 Pull Request Template

Thank you for your contribution to **SparkDQ**! 🎉  
Please take a moment to fill out this template to help us review your pull request effectively.

---

## 📌 What does this PR do?

<!-- Please provide a concise description of your changes.  
Example: "Adds a new numeric-between-check for row-level validation." -->

---

## 🧪 Checklist

- [ ] I followed the project's coding style.
- [ ] I added new unit tests for the changes (if applicable).
- [ ] All existing and new tests pass (`pytest --cov=sparkdq`).
- [ ] I updated the documentation (if applicable).
- [ ] My commit message follows [Conventional Commits](https://www.conventionalcommits.org/en/v1.0.0/).

---

## 🔎 Related Issues

<!-- Link to related issues, e.g.:  
"Fixes #42" or "Related to #99" -->

---

## 📂 Additional Notes

<!-- Anything else that reviewers should know?  
Examples: assumptions, edge cases, known limitations, screenshots, etc. -->

---

## ❤️ Thank You!

Thank you for contributing to **SparkDQ**!  
If this is your first contribution: welcome! 🎉  
If you’ve contributed before: thanks for coming back! 😊
